@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of a MIDI file
 
-our $VERSION = '0.1000';
+our $VERSION = '0.1001';
 
 use Moo;
 use strictures 2;
@@ -17,7 +17,6 @@ use MIDI::Simple;
 use MIDI::Util;
 use Music::Gestalt;
 use Music::Note;
-use Music::Tempo;
 
 
 has in_file => (
@@ -417,7 +416,7 @@ MIDI::Ngram - Find the top repeated note phrases of a MIDI file
 
 =head1 VERSION
 
-version 0.1000
+version 0.1001
 
 =head1 SYNOPSIS
 
@@ -592,7 +591,7 @@ L<Music::Note>
 
 L<MIDI::Simple>
 
-L<Music::Tempo>
+L<MIDI::Util>
 
 L<Music::Gestalt>
 
